
<!--
FrozenIsBool False
-->

#Doer

##Doc
----


> 
> The Doer defines instances that are going to decorate a big family of classes in this framework. 
> Staying on the idea, that one module should associate
> one class, now a decorated class by a Doer should have a NameStr that is 
> a DoStr and express also method a method with the name <DoStr>[0].lower()+<DoStr>[1:]
> All the attributes that are controlling this method process are <DoingStr><MiddleStr><TypeStr>
> and all the ones resetted during the method are <DoneStr><MiddleStr><TypeStr>.
> This helps a lot for defining a fisrt level of objects that are acting like input-output controllers.
> 
> 

----

<small>
View the Doer notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Doer.ipynb)
</small>

